# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-08 07:59
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_import', '0002_auto_20170807_2327'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xlscolumn',
            name='destination',
            field=models.CharField(choices=[('product_type', 'Product type'), ('collection', 'Collection'), ('extra_collection', 'Extra collection'), ('vendor', 'Vendor'), ('product', 'Product'), ('external_id', 'External ID'), ('product_image', 'Product image'), ('product_property', 'Product property'), ('price', 'Price'), ('quantity', 'Quantity'), ('product_status', 'Status')], help_text='See documentation for supported values.', max_length=100, verbose_name='Destination'),
        ),
    ]
