# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-08 11:33
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_catalog', '0020_auto_20170808_1104'),
        ('pcart_import', '0005_auto_20170808_1248'),
    ]

    operations = [
        migrations.CreateModel(
            name='XLSImportHistory',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('success', models.BooleanField(default=True, verbose_name='Success')),
                ('message', models.TextField(blank=True, default='', verbose_name='Message')),
                ('added', models.DateTimeField(auto_now_add=True, verbose_name='Added')),
            ],
            options={
                'verbose_name_plural': 'XLS Import history',
                'ordering': ['added'],
                'verbose_name': 'XLS Import history',
            },
        ),
        migrations.AlterModelOptions(
            name='xlspricelist',
            options={'ordering': ['added'], 'verbose_name': 'XLS Price list', 'verbose_name_plural': 'XLS Price lists'},
        ),
        migrations.AddField(
            model_name='xlsimporthistory',
            name='price_list',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='history', to='pcart_import.XLSPriceList', verbose_name='Price list'),
        ),
        migrations.AddField(
            model_name='xlsimporthistory',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='xls_import_history', to='pcart_catalog.Product', verbose_name='Product'),
        ),
    ]
