# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-08 11:34
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_import', '0006_auto_20170808_1433'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xlsimporthistory',
            name='product',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='xls_import_history', to='pcart_catalog.Product', verbose_name='Product'),
        ),
    ]
