# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-10-09 10:40
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_import', '0007_auto_20170808_1434'),
    ]

    operations = [
        migrations.AddField(
            model_name='xlsimportprofile',
            name='language',
            field=models.CharField(default='uk', max_length=10, verbose_name='Language'),
            preserve_default=False,
        ),
    ]
