# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-07 20:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_import', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xlspricelist',
            name='status',
            field=models.CharField(choices=[('new', 'New'), ('processing', 'Processing'), ('success', 'Success'), ('with_errors', 'With errors')], default='new', max_length=70, verbose_name='Status'),
        ),
    ]
