# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-08-08 09:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_import', '0003_auto_20170808_1059'),
    ]

    operations = [
        migrations.AlterField(
            model_name='xlscolumn',
            name='column_index',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='Column index'),
        ),
    ]
